@@ -32,6 +32,8 @@ bool Methods::scrFeature(void)
 	dtmf_digits[digit_count] = 0;
 	opt = getValue(dtmf_digits);
 
+	if(!strcmp(var_pid, var_recall) && time_joined)
+		exitCall("release");
         if(r)
         {
                 memset(&event, 0, sizeof(event));
@@ -39,6 +41,7 @@ bool Methods::scrFeature(void)
                 event.peer = this;
                 r->queEvent(&event);
         }
+	time_joined = 0;
 	strcpy(var_recall, "none");
 
         if(!framing || framing == TIMEOUT_INF)
