@@ -266,9 +266,10 @@ bool BayonneRPC::parseCall(char *cp)
 				return false;
 
 			header.prefix = method;
-			header.method = method = strchr(method, '.');
+			method = strchr(method, '.');
 			if(method)
 				*(method++) = 0;
+			header.method = method;
 
 			cp += 12;
 			break;
@@ -552,6 +553,8 @@ bool BayonneRPC::buildResponse(const char *fmt, ...)
 			break;
 		case ')':
 			struct_flag = false;
+			if(!map_flag && !array_flag)
+				end_flag = true;
 			count += xmlformat(buffer + count, max - count, 
 				" </struct></value>\r\n");
 			break;
