@@ -50,7 +50,6 @@ ScriptInterp(), audio()
 	state.menu = NULL;
 	peer = NULL;
 	connecting = false;
-	call = NULL;
 	ring = NULL;
 
 	if(!translator)
@@ -72,6 +71,7 @@ ScriptInterp(), audio()
 	strcpy(var_pid, "none");
 	strcpy(var_recall, "none");
 	strcpy(var_joined, "none");
+	time_joined = 0;
 	var_sid[0] = 0;
 	dtmf_digits = NULL;
 	digit_count = ring_count = 0;
@@ -102,25 +102,31 @@ BayonneSession::~BayonneSession()
 	finalize();
 }
 
-void BayonneSession::setCall(Call *c, const char *r)
+void BayonneSession::enterCall(void)
 {
-	if(call && c == call)
-		return;
+	BayonneService *svc = BayonneService::first;
 
-	if(call)
-		call->detach(r);
+	BayonneBinder::binder->makeCall(this);
 
-	call = c;
-	if(call)
-		call->attach();
+	while(svc)
+	{
+		svc->enteringCall(this);
+		svc = svc->next;
+	}
 }
 
-void BayonneSession::makeCall(const char *from)
+void BayonneSession::exitCall(const char *reason)
 {
-	if(call)
-		call->detach();
+        BayonneService *svc = BayonneService::first;
 
-	call = new Call(this, from);
+	setSymbol("session.terminated", reason);
+	BayonneBinder::binder->dropCall(this);
+
+        while(svc)
+        {
+                svc->exitingCall(this);
+                svc = svc->next;
+        }
 }
 
 void BayonneSession::incIncomingAttempts(void)
@@ -186,11 +192,19 @@ void BayonneSession::initialize(void)
 
 void BayonneSession::detach(void)
 {
+	BayonneService *svc = BayonneService::first;
+
 	answered = false;
 	digit_count = ring_count = 0;
 
 	disableDTMF();
 
+	while(svc)
+	{
+		svc->detachSession(this);
+		svc = svc->next;
+	}
+
 	ScriptInterp::detach();
 	var_sid[0] = 0;
 	strcpy(var_rings, "0");
@@ -286,6 +300,17 @@ bool BayonneSession::isRefer(void)
         return false;
 }
 
+bool BayonneSession::isAssociated(void)
+{
+	if(time_joined)
+		return true;
+
+	if(!strcmp(var_joined, var_pid) && strcmp(var_pid, "none"))
+		return true;
+
+	return false;
+}
+
 bool BayonneSession::isJoined(void)
 {
 	if(state.handler == &BayonneSession::stateJoin)
@@ -1049,6 +1074,7 @@ void BayonneSession::setState(state_t id)
 Script::Name *BayonneSession::attachStart(Event *event)
 {
 	BayonneSession *parent = event->start.parent;
+	BayonneService *svc = BayonneService::first;
 	const char *id;
 	Name *scr = event->start.scr;
 	ScriptImage *img = event->start.img;
@@ -1058,6 +1084,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	Line *line;
 	char buf[65];
 	struct tm *dt, dtr;
+	const char *cp;
 
 	if(!img)
 	{
@@ -1208,6 +1235,12 @@ final:
 		setConst("session.display", parent->getSymbol("session.display"));
 		strcpy(var_pid, parent->var_sid);
 		strcpy(var_joined, parent->var_sid);
+		cp = parent->getSymbol("session.authorized");
+		if(cp && *cp)
+			setConst("session.authorized", cp);
+		cp = parent->getSymbol("session.identity");
+		if(cp && *cp)
+			setConst("session.associated", cp);
 	}
 	else
 		state.join.answer_timer = 0;
@@ -1220,6 +1253,12 @@ final:
 	else if(!did)
 		setConst("session.dialed", event->start.dialing);
 
+	while(svc)
+	{
+		svc->attachSession(this);
+		svc = svc->next;
+	}
+
 	return scr;
 }
 	
@@ -1399,8 +1438,6 @@ void BayonneSession::makeIdle(void)
 	Symbol *sym;
 	Event event;
 
-	setCall(NULL);
-
 	if(ring)
 	{
 		Ring::detach(ring);
@@ -1467,6 +1504,10 @@ void BayonneSession::makeIdle(void)
 			event.id = seizure;
 		parent->queEvent(&event);
 	}
+	if(time_joined)
+		exitCall("disconnect");
+
+	time_joined = 0;
 	strcpy(var_joined, "none");
 	strcpy(var_pid, "none");
 	starting = false;
