@@ -1363,6 +1363,8 @@ bool BayonneSession::stateJoin(Event *event)
 		clrAudio();
 		return true;
         case ENTER_STATE:
+		if(!strcmp(var_recall, var_pid) && time_joined)
+			exitCall("release");
 		p = getSid(var_recall);
 		if(p && p != state.join.peer)
 		{
@@ -1378,8 +1380,16 @@ bool BayonneSession::stateJoin(Event *event)
 		if(state.join.dtmf && !dtmf)
 			dtmf = enableDTMF();
                 setSymbol("script.error", "none");
-		if(call)
-			call->start();
+		if(!strcpy(var_pid, peer->var_sid))
+		{
+			if(!time_joined)
+			{
+				time(&time_joined);
+				enterCall();
+			}
+		}
+		else
+			time_joined = 0;
                 return true; 
 	case PEER_REFER:
 		if(!peer || peer != event->peer)
@@ -1490,7 +1500,6 @@ bool BayonneSession::stateJoin(Event *event)
 	return rtn;
 
 part:
-	setCall(NULL, msg);
 	if(scriptEvent(msg))
 		state.join.hangup = false;
 	else if(signalScript(SIGNAL_PART))
@@ -1596,7 +1605,6 @@ bool BayonneSession::stateRefer(Event *event)
 	case DROP_REFER:
 		if(event->peer != state.join.peer)
 			return false;
-		setCall(NULL, "part::disconnect");
 		if(scriptEvent("part:disconnect"))
 			state.join.hangup = false;
 		else if(signalScript(SIGNAL_PART))
@@ -1611,7 +1619,11 @@ bool BayonneSession::stateRefer(Event *event)
 	case DROP_RECALL:
 		if(event->peer != state.join.peer)
 			return false;
-		setCall(NULL, "part:transfer");
+		if(time_joined)
+		{
+			exitCall("transfer");
+			time_joined = 0;
+		}
 		if(scriptEvent("part:transfer"))
 			state.join.hangup = false;
 		else if(signalScript(SIGNAL_PART))
@@ -1722,7 +1734,13 @@ bool BayonneSession::stateStandby(Event *event)
 {
 	if(enterStandby(event))
 		return true;
-        return enterCommon(event);
+
+	if(event->id == MAKE_UP)
+	{
+		setState(STATE_IDLE);
+		return true;
+	}
+	return false;
 }
 
 bool BayonneSession::stateFinal(Event *event)
@@ -2263,7 +2281,6 @@ bool BayonneSession::stateRunning(Event *event)
 			default:
 				incIncomingComplete();
 			}			
-			BayonneService::active(this);
 		}
 		if(state.pid)
 			newTid();
@@ -2334,7 +2351,6 @@ bool BayonneSession::stateHangup(Event *event)
 	if(event->id == ENTER_STATE)
 	{
 		decActiveCalls();
-		BayonneService::detach(this);
 		holding = false;
 	}
 
@@ -2521,6 +2537,10 @@ bool BayonneSession::enterCommon(Event *event)
 			return false;
 		return true;
 
+	case MAKE_DOWN:
+		makeIdle();
+		setState(STATE_DOWN);
+		return true;
 	case MAKE_IDLE:
 		if(offhook)
 		{
