@@ -23,6 +23,10 @@
 #include <private.h>
 #endif
 
+#ifndef	OSIP2_LIST_PTR
+#define	OSIP2_LIST_PTR
+#endif
+
 namespace sipdriver {
 using namespace ost;
 using namespace std;
@@ -363,6 +367,38 @@ bool Driver::isReachable(const char *proxy)
 	return rtn;
 }
 
+bool Driver::isAuthorized(const char *userid, const char *secret)
+{
+	char buf[65];
+	ScriptImage *img;
+	Registry *reg;
+	bool rtn = false;
+
+	if(!userid)
+		return false;
+
+	if(strchr(userid, '@'))
+		return false;
+
+	img = useImage();
+	if(!img)
+		return false;
+
+	if(!strnicmp(userid, "sip:", 4) || !strnicmp(userid, "sip/", 4))
+		userid += 4;
+
+	snprintf(buf, sizeof(buf), "uri.%s",  userid);
+	reg = (Registry *)img->getPointer(buf);
+	if(reg)
+	{
+		if(!stricmp(reg->type, "ext"))
+			if(!strcmp(reg->secret, secret))
+				rtn = true;
+	}
+	endImage(img);
+	return rtn;
+}	
+
 bool Driver::isExternal(const char *ext)
 {
 	char buf[65];
@@ -381,7 +417,7 @@ bool Driver::isExternal(const char *ext)
 	if(!img)
 		return false;
 
-	if(!strnicmp(ext, "sip:", 4))
+	if(!strnicmp(ext, "sip:", 4) || !strnicmp(ext, "sip/", 4))
 		ext += 4;
 
 	snprintf(buf, sizeof(buf), "uri.%s", ext);
@@ -420,7 +456,7 @@ bool Driver::isRegistered(const char *ext)
 	if(!img)
 		return false;
 
-	if(!strnicmp(ext, "sip:", 4))
+	if(!strnicmp(ext, "sip:", 4) || !strnicmp(ext, "sip/", 4))
 		ext += 4;
 
 	snprintf(buf, sizeof(buf), "uri.%s", ext);
@@ -462,7 +498,7 @@ bool Driver::isAvailable(const char *ext)
 	if(!img)
 		return false;
 
-	if(!strnicmp(ext, "sip:", 4))
+	if(!strnicmp(ext, "sip:", 4) || !strnicmp(ext, "sip/", 4))
 		ext += 4;
 
 	snprintf(buf, sizeof(buf), "uri.%s", ext);
@@ -502,12 +538,13 @@ bool Driver::isAvailable(const char *ext)
 	return rtn;
 }
 
-unsigned Driver::getRegistration(regauth_t *data, unsigned count)
+unsigned Driver::getRegistration(regauth_t *data, unsigned count, const char *id)
 {
 	unsigned idx = 0;
 	ScriptImage *img = useImage();
 	Registry *reg = (Registry *)img->getPointer("_sip_registry_");
 	bool ext, gw, anon;
+	const char *uid;
 
 	while(idx < count && reg)
 	{
@@ -521,6 +558,16 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 		else if(!stricmp(reg->type, "anon"))
 			anon = true;
 
+		uid = reg->localid;
+		if(!uid)
+			uid = reg->userid;
+
+		if(id && !uid)
+			goto skip;
+
+		if(id && stricmp(id, uid))
+			goto skip;
+
 		if(anon)
 			data[idx].remote = "*";
 		else if((ext || gw) && !reg->traffic->active)
@@ -529,7 +576,7 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 			data[idx].remote = reg->proxy + 4;
 		else
 			data[idx].remote = reg->proxy;
-		data[idx].userid = reg->userid;
+		data[idx].userid = uid;
 		data[idx].type = reg->type;
 		if(anon)
 			data[idx].status = "active";
@@ -583,6 +630,7 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 		data[idx].active_calls = reg->traffic->active_calls;
 		data[idx].call_limit = reg->call_limit;
 		++idx;
+skip:
 		reg = reg->next;
 	}
 
@@ -604,8 +652,8 @@ bool Driver::getAuthentication(Session *s, osip_message_t *resp)
 
         if(resp)
         {
-		prx_auth = (osip_proxy_authenticate_t*)osip_list_get(resp->proxy_authenticates, 0);
-                www_auth = (osip_proxy_authenticate_t*)osip_list_get(resp->www_authenticates,0);
+		prx_auth = (osip_proxy_authenticate_t*)osip_list_get(OSIP2_LIST_PTR resp->proxy_authenticates, 0);
+                www_auth = (osip_proxy_authenticate_t*)osip_list_get(OSIP2_LIST_PTR resp->www_authenticates,0);
         }
 
 	if(!cp)
@@ -653,8 +701,8 @@ void Driver::setAuthentication(Registry *reg, osip_message_t *resp)
 
 	if(resp)
 	{
-		prx_auth = (osip_proxy_authenticate_t*)osip_list_get(resp->proxy_authenticates, 0);
-        	www_auth = (osip_proxy_authenticate_t*)osip_list_get(resp->www_authenticates,0);
+		prx_auth = (osip_proxy_authenticate_t*)osip_list_get(OSIP2_LIST_PTR resp->proxy_authenticates, 0);
+        	www_auth = (osip_proxy_authenticate_t*)osip_list_get(OSIP2_LIST_PTR resp->www_authenticates,0);
 	}
 
 	if(prx_auth)
@@ -1252,9 +1300,9 @@ fail401:
 	if(stricmp(auth->response, resp_hash))
 		goto fail401;
 
-	while(osip_list_eol(sevent->request->contacts, pos) == 0)
+	while(osip_list_eol(OSIP2_LIST_PTR sevent->request->contacts, pos) == 0)
 	{
-		contact = (osip_contact_t *)osip_list_get(sevent->request->contacts, pos++);
+		contact = (osip_contact_t *)osip_list_get(OSIP2_LIST_PTR sevent->request->contacts, pos++);
 		if(contact && contact->url)
 			break;
 	}
@@ -2535,9 +2583,9 @@ answer:
 				eXosip_unlock();
 				goto cleanup;
 			}
-			while(!osip_list_eol(remote_sdp->m_medias, mpos))
+			while(!osip_list_eol(OSIP2_LIST_PTR remote_sdp->m_medias, mpos))
 			{
-				remote_media = (sdp_media_t *)osip_list_get(remote_sdp->m_medias, mpos++);
+				remote_media = (sdp_media_t *)osip_list_get(OSIP2_LIST_PTR remote_sdp->m_medias, mpos++);
 				if(!remote_media)
 					continue;
 
@@ -2550,9 +2598,9 @@ answer:
 				tmp = NULL;
 				pos = 0;
 
-				while(!osip_list_eol(remote_media->a_attributes, pos))
+				while(!osip_list_eol(OSIP2_LIST_PTR remote_media->a_attributes, pos))
 				{
-					attr = (sdp_attribute_t *)osip_list_get(remote_media->a_attributes, pos++);
+					attr = (sdp_attribute_t *)osip_list_get(OSIP2_LIST_PTR remote_media->a_attributes, pos++);
 					if(!attr)
 						continue;
 
@@ -2985,7 +3033,9 @@ sip480:
 
 				if(!strnicmp(reg->type, "ext", 3))
 				{
-					session->setConst("session.identity", reg->localid);
+					snprintf(buf, sizeof(buf), "sip:%s", reg->localid);
+					session->setConst("session.authorized", buf);
+					session->setConst("session.identity", buf);
 					session->setConst("session.group", reg->group);
 				}
 				else
@@ -2993,7 +3043,6 @@ sip480:
 			
 				snprintf(digit, sizeof(digit), "%d", sinstance);
 				session->setConst("session.instance", digit);
-				BayonneService::notify(session);
 			}
 			else
 			{
@@ -3007,7 +3056,6 @@ sip480:
 			}
                         snprintf(digit, sizeof(digit), "%d", sinstance);                                
 			session->setConst("session.instance", digit);
-                        BayonneService::notify(session);
 
 			sinstance = 0;
 			sreg = NULL;
@@ -3073,9 +3121,9 @@ sip415:
 			data_rtpmap = session->sdpEncoding();
 			session->data_payload = session->sdpPayload();
 			audio_payload = NULL;
-			while(!osip_list_eol(remote_sdp->m_medias, mpos))
+			while(!osip_list_eol(OSIP2_LIST_PTR remote_sdp->m_medias, mpos))
 			{
-				remote_media = (sdp_media_t *)osip_list_get(remote_sdp->m_medias, mpos++);
+				remote_media = (sdp_media_t *)osip_list_get(OSIP2_LIST_PTR remote_sdp->m_medias, mpos++);
 				if(!remote_media)
 					continue;
 
@@ -3089,9 +3137,9 @@ sip415:
 				pos = 0;
 				inactive = false;				
 
-				while(!osip_list_eol(remote_media->a_attributes, pos))
+				while(!osip_list_eol(OSIP2_LIST_PTR remote_media->a_attributes, pos))
 				{
-					attr = (sdp_attribute_t *)osip_list_get(remote_media->a_attributes, pos++);
+					attr = (sdp_attribute_t *)osip_list_get(OSIP2_LIST_PTR remote_media->a_attributes, pos++);
 					if(!attr)
 						continue;
 					tmp = attr->a_att_field;
@@ -3129,9 +3177,9 @@ sip415:
  				}
 			
 				pos = 0;
-				while(!osip_list_eol(remote_media->m_payloads, pos) && !audio_payload)
+				while(!osip_list_eol(OSIP2_LIST_PTR remote_media->m_payloads, pos) && !audio_payload)
 				{
-					tmp = (char *)osip_list_get(remote_media->m_payloads, pos++);
+					tmp = (char *)osip_list_get(OSIP2_LIST_PTR remote_media->m_payloads, pos++);
 					if(!tmp || !*tmp)
 						continue;
 
