@@ -217,13 +217,14 @@ public:
 	bool isReachable(const char *proxy);
 	bool isRegistered(const char *ext);
 	bool isAvailable(const char *ext);
+	bool isAuthorized(const char *userid, const char *secret);
 
 	void run(void);
 
 	inline Level getSilence(void)
 		{return silence;};
 
-	unsigned getRegistration(regauth_t *data, unsigned count);
+	unsigned getRegistration(regauth_t *data, unsigned count, const char *id);
 };
 
 class RTPStream : public SymmetricRTPSession, public AudioBase, private TimerPort, private Mutex, public Bayonne
